## 聊天模块使用

### 说明

> 该项目依赖父项目的插件['vue', 'axios', 'element-plus', '@element-plus/icons-vue', 'pinia']，且在 vue3 的环境下运行。

> 该项目导出 { installChat, ChatViews, ChatRoom } 分别为初始化函数，聊天模块整体组件，聊天框组件。

### 用法

1. 安装

```json
"qmp-im-s": "git+https://git.qmpoa.com/fe_common_lib/qmp-im-s.git#v0.0.3"(看下最新tag,最好使用最新的)
```

2. 使用

2.1 在 main.js 文件引入 installChat 方法，并执行

```js
import { installChat } from 'qmp-im-s';

const app = createApp(App);

installChat(app, import.meta.env.VITE_APP_MODE === `prod` ? 'prod' : 'dev');
```

2.2 聊天模块整体引入事例
![示例图](image.png)

```vue
<template>
  <ChatViews
    class="im"
    :userInfo="{
      name: '张亚军',
      icon: 'https://img1.qimingpian.cn/uploadImg/202403/65fc056f82eeb.png',
      uuid: '',
      uniq_id: '13932377887',
    }"
  />
</template>
<script setup lang="ts">
import { ref } from 'vue';
import 'qmp-im-s/lib/export.css';
import { ChatViews } from 'qmp-im-s';
</script>
<style lang="scss">
.im {
  height: 100vh;
}
</style>
```

2.2 聊天弹框使用事例

![组件示例图](![alt text](image-1.png))

```vue
<template>
  <el-button @click="toChat">点击聊天</el-button>
  <el-dialog v-model="dialogVisible" align-center width="700px" class="chat-dialog">
    <ChatRoom
      v-if="dialogVisible"
      :userInfo="{
        name: '张亚军',
        icon: 'https://img1.qimingpian.cn/uploadImg/202403/65fc056f82eeb.png',
        uuid: '',
        uniq_id: '13932377887',
      }"
      show_content="<p>反馈类型：项目反馈</p><p>反馈对象：中国移动</p>"
      to_uniq_id="15101084656"
    />
  </el-dialog>
</template>
<script setup lang="ts">
import { ref } from 'vue';
import { ChatRoom } from 'qmp-im-s';
import 'qmp-im-s/lib/export.css';
const dialogVisible = ref(false);
const toChat = () => {
  dialogVisible.value = true;
};
</script>
<style lang="scss">
.chat-dialog {
  .el-dialog__header {
    height: 1px !important;
    .el-dialog__headerbtn {
      margin-top: 64px;
      z-index: 1;
    }
  }
  .el-dialog__body {
    padding: 0;
    height: 80vh;
  }
}
</style>
```

### 参数说明

| 参数             | 说明                              | 类型           | 默认值 |
| :--------------- | :-------------------------------- | :------------- | ------ |
| userInfo         | 当前用户的信息                    | Object         |        |
| userInfo.name    | 当前用户名称                      | String         |        |
| userInfo.icon    | 当前用户的 icon                   | String         |        |
| userInfo.uniq_id | 当前用户 uniq_id，通常为手机号    | String         |        |
| userInfo.uuid    | 当前用户 passport 的 uuid(非必填) | String         |        |
| to_uniq_id       | 聊天对象的 uniq_id                | String         |        |
| env              | 当前运行环境                      | String         | 'prod' |
| show_content     | 聊天框回显内容                    | String（html） |        |
| source           | 来源                            | String         |  see   |

### 事件(ChatViews 组件)

| 事件名称       | 说明                   | 值     |
| -------------- | ---------------------- | ------ |
| chatPageActive | 点击通知弹框后触发     | null   |
| changeCount    | 全部未读熟发生变化触发 | number |
