import axios from 'axios';
import request from '@/utils/requestIm';
import requestBff from '@/utils/requestDoc';
import requestSL from '@/utils/requestSL';
/**
 * @file IM模块
 * IM接口接收formData类型数据
 */
import { IM_HOST, APP_BFF, IM_BFF_API, SL_API } from '@/api/baseApi';

/**
 * @description: 绑定用户聊天
 * @param {*} data
 * @return {*}
 */
export function API_bindUser(data: any) {
  return request({
    url: IM_HOST + '/im/bindUser',
    method: 'post',
    data,
  });
}

/**
 * @description: 获取会话列表
 * @param {*} data
 * @return {*}
 */
export function API_getRoomList(data: any) {
  return request({
    url: IM_HOST + '/im/getRoomList',
    method: 'post',
    data, // data.room_type: 0:一对一聊天 1:频道  2:企业
  });
}

/**
 * @description: 获取会话列表
 * @param {*} data
 * @return {*}
 */
export function API_getFoldRoomList(data: any) {
  return request({
    url: IM_HOST + '/im/getFoldRoomList',
    method: 'post',
    data, // data.room_type: 0:一对一聊天 1:频道  2:企业
  });
}

/**
 * @description: 获取消息列表
 * @param {*} data
 * @return {*}
 */
export function API_messageList(data: any) {
  return request({
    url: IM_HOST + '/im/messageList',
    method: 'post',
    data,
  });
}

/**
 * @description: 获取用户card信息
 * @param {*} uniq_id
 * @return {*}
 */
export function API_getCardInfo(data: { uniq_id: string }) {
  return requestSL({
    url: SL_API + '/api/s1/imid/card/info',
    method: 'post',
    data,
  });
}

/**
 * @description: 解密uniq_id
 * @param {*} uniq_id
 * @return {*}
 */
export function API_getUniqId(data: { uniq_id: string }) {
  return requestSL({
    url: SL_API + '/api/s3/im/getUniqId',
    method: 'post',
    data
  })
}

/**
 * @description: 设置卡片
 * @param {*} uuid, is_auth
 * @return {*}
 */
export function API_setCardAuth(data: { uuid: string; is_auth: number }) {
  return requestSL({
    url: SL_API + '/api/s1/card/auth',
    method: 'post',
    data
  })
}

/**
 * @description: 发送消息
 * @param {*} data
 * @return {*}
 */
export function API_sendMessage(data: any) {
  return request({
    url: IM_HOST + '/im/sendMessage',
    method: 'post',
    data,
  });
}

/**
 * @description: 创建会话
 * @param {*} data
 * @return {*}
 */
export function API_createRoom(data: any) {
  return request({
    url: IM_HOST + '/im/createRoom',
    method: 'post',
    data,
  });
}

/**
 * @description: 已读消息接口
 * @param {*} data
 * @return {*}
 */
export function API_upRead(data: any) {
  return request({
    url: IM_HOST + '/im/upRead',
    method: 'post',
    data,
  });
}

/**
 * @description: 获取未读消息条数
 * @param {*} data
 * @return {*}
 */
export function API_getUnReadTotal(data: any) {
  return request({
    url: IM_HOST + '/im/getUnReadTotal',
    method: 'post',
    data,
  });
}
/**
 * @file 获取签名信息
 */
export function api_getOssSign(data: any) {
  return request({
    url: IM_HOST + '/im/getOssSign',
    method: 'post',
    data,
  });
}
/**
 * @description: 获取用户信息接口
 * @param {any} data
 * @return {*}
 */
export function API_getUserInfo(data: any) {
  return request({
    url: IM_HOST + '/im/getUserInfo',
    method: 'post',
    data,
  });
}

/**
 * @description: 从分组中删除用户
 * @param {any} data
 * @return {*}
 */
export function API_delUserFromGroup(data: any) {
  return request({
    url: IM_HOST + '/im/delUserFromGroup',
    method: 'post',
    data,
  });
}

/**
 * @description: 上传图片
 * @param {any} data
 * @return {*}
 */
export function API_UPLOAD_IMG(id: any, file: any) {
  const imgData = new FormData();
  imgData.append('file', file);
  return axios
    .post(IM_HOST + '/im/uploadFile', imgData, {})
    .then((res: any) => {
      if (res.data.status === 0) {
        const data = res.data.data;
        return { id, data };
      }
    })
    .catch(error => {
      console.log(error);
    });
}

/**
 * @description: 上传其他文件
 * @param {any} data
 * @return {*}
 */
export function API_UPLOAD_FILE(file: any) {
  const imgData = new FormData();
  imgData.append('file', file);
  return axios
    .post(IM_HOST + '/im/uploadedFile', imgData, {})
    .then((res: any) => {
      return res;
    })
    .catch(error => {
      console.log(error);
    });
}

/**
 * @description: 消息撤回
 * @param {any} data
 * @return {*}
 */
export function API_MSG_WITHDRAW(data: any) {
  return request({
    url: IM_HOST + '/im/msgWithdraw',
    method: 'post',
    data,
  });
}
/**
 * @description: 获取群聊房间信息
 * @param {any} data
 * @return {*}
 */
export function API_roomInfo(data: any) {
  return request({
    url: IM_HOST + '/im/roomInfo',
    method: 'post',
    data,
  });
}

/**
 * @description: 获取群聊基本信息
 * @param {any} data
 * @return {*}
 */
export function API_showGroupDetail(data: any) {
  return request({
    url: IM_HOST + '/im/showGroupDetail',
    method: 'post',
    data,
  });
}

//加入群聊
export function API_joinChannel(data: any) {
  return request({
    url: IM_HOST + '/im/joinChannel',
    method: 'post',
    data,
  });
}

//退出群聊
export function API_exitFriendRoom(data: any) {
  return request({
    url: IM_HOST + '/im/exitFriendRoom',
    method: 'post',
    data,
  });
}

//解散群聊
export function API_dissolutionRoom(data: any) {
  return request({
    url: IM_HOST + '/im/dissolutionRoom',
    method: 'post',
    data,
  });
}

//创建群聊
export function API_createFriendRoom(data: any) {
  return request({
    url: IM_HOST + '/im/createFriendRoom',
    method: 'post',
    data,
  });
}

//邀请用户到群聊
export function API_joinFriendRoom(data: any) {
  return request({
    url: IM_HOST + '/im/joinFriendRoom',
    method: 'post',
    data,
  });
}

//踢人
export function API_kickMember(data: any) {
  return request({
    url: IM_HOST + '/im/kickMember',
    method: 'post',
    data,
  });
}

//设置房间信息
export function API_setChat(data: any) {
  return request({
    url: IM_HOST + '/im/setChat',
    method: 'post',
    data,
  });
}

//修改群名
export function API_updateRoom(data: any) {
  return request({
    url: IM_HOST + '/im/updateRoom',
    method: 'post',
    data,
  });
}

/**
 * @file 获取群聊广场
 */
export function api_channelList(data: any) {
  return request({
    url: IM_HOST + '/im/channelList',
    method: 'post',
    data,
  });
}

/**
 * @file 加入广场群
 */
export function api_joinChannel(data: any) {
  return request({
    url: IM_HOST + '/im/joinChannel',
    method: 'post',
    data,
  });
}

// 获取服务号，品牌号未读数
export function API_getUnReadTotalMany(data: any) {
  return request({
    url: IM_HOST + '/im/getUnReadTotalMany',
    method: 'post',
    data,
  });
}

/**
 * @description: 获取公司IM用户列表
 * @param {any} data
 * @return {*}
 */
export function API_getUserList(data: any) {
  return request({
    url: IM_HOST + '/im/getUserList',
    method: 'post',
    data,
  });
}

// 获取用户im信息
export function API_getImUsersInfos(data: { phone: string }) {
  return requestBff({
    url: IM_BFF_API + '/passport/usercenter/card/info',
    method: 'post',
    data,
  }).then(res => {
    handleContactItem(res.data || {});
    return res;
  });
}

// 新版接口和老版数据有一些差异
export function handleContactItem(obj) {
  obj.uniq_id = obj.phone; // 代码里基本都是使用的这个字段
}
