import axios from 'axios'
import { api_getOssSign } from '@/api/im/index'
import { useUserImStore } from '@/store/userIm'
import dayjs from 'dayjs'
import { randomStr } from '@/utils/tools'
import { imgTypes, isVideoType } from '@/utils/globalData'
import { specialCharacterDelete } from '@/utils/validate'
import { getVideoInfo, getOssVideoCover } from '@/utils/oss'
import UploadToOss from 'upload-to-oss'
import { DOC_API } from '@/api/baseApi'
import { action_updateMessage } from '@/components/chat-module/msgUtils/tempMessageAction'

export const handleFileUpload = async ({ file, id = '', custom_id = '' }) => {
  const { fileUpload } = UploadToOss({ file, base_dir: 'pan', baseUrl: DOC_API, channel: 4 })
  const uploadProgressCb = (data) => {
    console.log(data) // {progress}
    custom_id && action_updateMessage(custom_id, data)
  }
  const { size, url, md5 } = await fileUpload(uploadProgressCb)
  const name = file.name
  if (!url) {
    return {}
  } 
  const type = file.type.split('/')[1]
  if (imgTypes.includes(type)) {
    // 获取图片宽高
    let { width, height } = await getImageInfo(url)
    return {
      id,
      url,
      name,
      size_origin: size,
      md5,
      width,
      height
    }
  } else if (isVideoType(url, 1)) {
      const cover = getOssVideoCover(url, 5000, 570)
      const { duration, width, height } = await getVideoInfo(file)
    return {id, url, name, width, height, duration, cover, size_origin: size, md5 }
  }
  return { id, url, name, size_origin: size, md5 }
}
export const getImageInfo = async (url) => {
  let res1 = await axios.get(`${url}?x-oss-process=image/info`)
  const { ImageHeight, ImageWidth, FileSize, Format } = res1.data || {}
  return {
    size: Number(FileSize?.value),
    ext: Format.value,
    width: Number(ImageWidth?.value),
    height: Number(ImageHeight?.value)
  }
}
