import Quill from 'quill';

const Inline = Quill.import('blots/inline');
class LinkIM extends Inline {
  static create(value) {
    const node = super.create(value);
    node.setAttribute('href', this.sanitize(value));
    node.setAttribute('target', 'new-tab');
    node.addEventListener('click', e => {
      if (!e.target.className.includes('im-doc-link')) {
        e.stopPropagation();
        e.preventDefault();
      }
    });
    return node;
  }

  static formats(domNode) {
    return domNode.getAttribute('href');
  }

  static sanitize(url) {
    return sanitize(url, this.PROTOCOL_WHITELIST) ? url : this.SANITIZED_URL;
  }

  format(name, value) {
    if (name !== this.statics.blotName || !value) {
      super.format(name, value);
    } else {
      this.domNode.setAttribute('href', this.constructor.sanitize(value));
    }
  }
}
LinkIM.blotName = 'LinkIM';
LinkIM.tagName = 'A';
LinkIM.SANITIZED_URL = 'about:blank';
LinkIM.PROTOCOL_WHITELIST = ['http', 'https', 'mailto', 'tel'];

function sanitize(url, protocols) {
  const anchor = document.createElement('a');
  anchor.href = url;
  const protocol = anchor.href.slice(0, anchor.href.indexOf(':'));
  return protocols.indexOf(protocol) > -1;
}

export default LinkIM;
