import { computed, onBeforeUnmount, ref, shallowRef, watch } from 'vue';
import { KeyboardSelect } from '@/utils/KeyboardSelect';

export const useSearchChat = ({
  handleSelectSearch,
  onSelectChange,
  keywords,
  props,
  emits,
}: any) => {
  const showSearch = ref(false);
  const searchListRef = ref();
  const searchInputRefc = ref();
  const searchList = shallowRef({});
  const changePopoverState = (state = false) => {
    showSearch.value = state;
  };
  let instance: any;
  let chat: any = {
    user: [],
    group: [],
    business: [],
    assistant: [],
  };
  watch(searchList, () => {
    instance && instance.init(0);
  });
  const destroy = () => {
    if (instance) {
      instance.clear();
      instance = null;
    }
  };
  watch(showSearch, val => {
    destroy();
    if (val) {
      instance = new KeyboardSelect({
        scrollEl: searchListRef.value,
        itemElClassName: 'search-item',
        handleHover: true,
        selectIndex: 0,
        enterFn: (el: any) => {
          const { item, type } = el.dataset;
          if (type === 'user') {
            handleSelectSearch(JSON.parse(item), () => {
              changePopoverState(false);
            });
          } else if (type === 'more') {
            handleSearchMore();
          }
        },
        onSelectChange,
      });
    }
  });
  const onClickOutside = (e: any) => {
    const inputDom = document.querySelector('.search-input .input-search');
    if (
      !searchListRef.value?.contains(e.target) &&
      !inputDom?.contains(e.target) &&
      e.target !== searchListRef.value &&
      e.target !== inputDom
    ) {
      changePopoverState(false);
    }
  };
  const handleSearchMore = () => {
    changePopoverState(false);
  };
  const handleSearchInput = () => {
    const searchV = searchInputRefc.value.ref.value.trim();
    if (!searchV) {
      clearList();
      showSearch.value = false;
      return;
    }
    chat = {
      user: [],
      group: [],
      business: [],
      content: [],
      assistant: [],
    };
    props.allList.forEach((item: any) => {
      if (
        item.room_type === 0 &&
        item.type === 'user' &&
        item.name.toLowerCase().includes(searchV.toLowerCase())
      ) {
        chat.user.push(item);
      }
      if (item.room_type >= 1 && item.name.toLowerCase().includes(searchV.toLowerCase())) {
        chat.group.push(item);
      }
      if (item.type === 'business' && item.name.toLowerCase().includes(searchV.toLowerCase())) {
        chat.business.push(item);
      }
      if (item.type === 'content' && item.name.toLowerCase().includes(searchV.toLowerCase())) {
        chat.content.push(item);
      }
      if (
        item.room_type === 0 &&
        item.type === 'tool' &&
        item.name.toLowerCase().includes(searchV.toLowerCase())
      ) {
        chat.assistant.push(item);
      }
    });
    showSearch.value = true;
    searchList.value = chat;
  };
  function clearList() {
    emits('update:word', '');
    searchList.value = {};
  }
  watch(
    () => showSearch.value,
    val => {
      if (val) {
        document.addEventListener('mousedown', onClickOutside, true);
      } else {
        document.removeEventListener('mousedown', onClickOutside, true);
      }
    },
    { immediate: true },
  );
  const isEmptyData = computed(() => {
    let n = 0;
    Object.values(searchList.value).forEach(item => {
      n += item.length;
    });
    return n === 0;
  });
  onBeforeUnmount(destroy);
  return {
    showSearch,
    searchListRef,
    searchInputRefc,
    searchList,
    changePopoverState,
    handleSearchMore,
    handleSearchInput,
    isEmptyData,
  };
};
