import { openDB } from 'idb';
import type { IDBPDatabase } from 'idb';
import { useUserImStore } from '@/store/userIm';
import { ENV } from '@/api/baseApi';
export const getUUID = () => {
  const imStore = useUserImStore();
  return `${ENV}_${imStore.user_im_id}`;
};

const DEVELOP_VERSION = 3;
let dbInstance: IDBPDatabase = null;

export const getStoreNames = (db: IDBPDatabase) => {
  return Array.from(db.objectStoreNames) as string[];
};
type callBack = (db: IDBPDatabase, arr: string[]) => void;
const openChatDB = (uuid: string, version: number, fn?: callBack, times = 0) => {
  console.log('openChatDB_begin');
  return openDB(`im_${uuid}`, version, {
    upgrade(db: IDBPDatabase, oldV, newV, transaction) {
      const storeArr = getStoreNames(db);
      // 会话表
      !storeArr.includes('chat') && db.createObjectStore(`chat`, { keyPath: 'chat_id' });
      // 临时消息表updateChatDB
      if (!storeArr.includes('temp_message')) {
        const store = db.createObjectStore(`temp_message`, { keyPath: 'custom_id' });
        store.createIndex('create_time', 'create_time', { unique: false });
        store.createIndex('custom_id', 'custom_id', { unique: true });
      }
      // 消息表
      if (!storeArr.includes('message_list')) {
        db.createObjectStore(`message_list`, { keyPath: 'room_id' });
      }
      fn && fn(db, storeArr);
    },
    blocking(currentVersion, blockedVersion, event) {
      event.target.close();
      dbInstance = null;
    },
  });
};

export const getChatDB = async () => {
  if (dbInstance) {
    return dbInstance;
  }
  console.log('getChatDB_begin');
  dbInstance = await openChatDB(getUUID(), DEVELOP_VERSION);
  console.log('getChatDB_end');
  return dbInstance;
};
