import { getChatDB, getStoreNames } from './common';
import { removePendingMessage, action_updateMessage } from '../msgUtils/tempMessageAction';
import type { IDBPDatabase } from 'idb';
import { socket_resendMessage } from '../msgUtils/socketAction';

// 一分钟之内自动重发5次
type storeProps = ['temp_message'];
const storeName = 'temp_message';

// 获取发送未成功消息消息
export const getTempMessageFromDB = async (chat_id: string) => {
  console.log('getChatDB_begin', chat_id);
  const db = await getChatDB();
  // console.log('getChatDB_end', db)
  return await getMessageList(db, chat_id);
};

const getMessageList = async (db: IDBPDatabase<any>, chat_id: string) => {
  console.log('getMessageList_begin');
  const arr = [];
  const store = db.transaction<storeProps>([storeName]).store;
  let cursor = await store.index('create_time').openCursor(null, 'prev');
  while (cursor) {
    if (cursor.value.room_id == chat_id) arr.push(cursor.value);
    cursor = await cursor.continue();
  }
  console.log('getMessageList_end', arr);
  return arr;
};
// 更新发送未成功聊天
export const updateTempMessage = async (custom_id: string, data: any) => {
  if (custom_id) {
    const db = await getChatDB();
    const storeArr = getStoreNames(db);
    if (storeArr.includes(storeName)) {
      const tx = db.transaction(storeName, 'readwrite') as any;
      const store = tx.objectStore(storeName);
      const message = await store.get(custom_id);
      if (message) await store.put(Object.assign(message, data));
      await tx.done;
      if (+data.is_read === 3) {
        removePendingMessage(custom_id);
      }
    }
  }
};
// 添加发送未成功消息
export const addTempMessageToDB = async (message: any) => {
  const db = await getChatDB();
  const storeArr = getStoreNames(db);
  if (storeArr.includes(storeName)) {
    const tx = db.transaction([storeName], 'readwrite') as any;
    return [tx.store.put(message), tx.done];
  }
};

export const deleteTempMessageFromDB = async (custom_id: string) => {
  const db = await getChatDB();
  const storeArr = getStoreNames(db);
  if (storeArr.includes(storeName)) {
    db.delete(storeName, custom_id);
  }
  removePendingMessage(custom_id);
};

export const updateTempMessageState = async ({ sendState }: { sendState: string }) => {
  const db = await getChatDB();
  const storeArr = getStoreNames(db);
  const arr = [];
  if (storeArr.includes(storeName)) {
    let cursor = await db
      .transaction<storeProps, 'readwrite'>([storeName], 'readwrite')
      .store.openCursor();
    while (cursor) {
      if (cursor.value.sendState === 2) {
        const value = { ...cursor.value };
        arr.push(value.custom_id);
        value.sendState = sendState;
        await cursor.update(value);
      }
      cursor = await cursor.continue();
    }
  }
  arr.map(custom_id => {
    removePendingMessage(custom_id);
  });
};
// 设置重新发送标识
export const setReSendState = async () => {
  const db = await getChatDB();
  const storeArr = getStoreNames(db);
  const arr = [];
  if (storeArr.includes(storeName)) {
    let cursor = await db
      .transaction<storeProps, 'readwrite'>([storeName], 'readwrite')
      .store.openCursor();
    while (cursor) {
      if (cursor.value.is_read === 2) {
        const value = { ...cursor.value };
        arr.push(value.custom_id);
        value.isAutoResend = true;
        value.sendTotal++;
        await cursor.update(value);
      }
      cursor = await cursor.continue();
    }
  }
};
const getTempMessageByFilter = async (filter: (current: any) => boolean) => {
  const db = await getChatDB();
  const storeArr = getStoreNames(db);
  const arr = [];
  if (storeArr.includes(storeName)) {
    let cursor = await db
      .transaction<storeProps, 'readwrite'>([storeName], 'readwrite')
      .store.openCursor();
    while (cursor) {
      if (filter(cursor.value)) {
        arr.push(cursor.value);
      }
      cursor = await cursor.continue();
    }
  }
  return arr;
};
// socket连接成功后重新发送请求
export const reSendAfterSocketSuccess = async (socketCreateTime: string) => {
  const db = await getChatDB();
  const storeArr = getStoreNames(db);
  const arr = [];
  if (storeArr.includes(storeName)) {
    let cursor = await db
      .transaction<storeProps, 'readwrite'>([storeName], 'readwrite')
      .store.openCursor();
    // console.log('cursor', cursor, socketCreateTime)
    while (cursor) {
      if (
        cursor.value.is_read === 2 &&
        cursor.value.isAutoResend &&
        cursor.value.create_time <= socketCreateTime
        // cursor.value.progress === 1
      ) {
        arr.push(cursor.value);
        console.log('arr===', arr);
      }
      cursor = await cursor.continue();
    }
    arr
      .sort((a, b) => {
        return a.create_time - b.create_time;
      })
      .forEach(item => {
        console.log('当前消息', item);
        socket_resendMessage(item);
        if (item.sendTotal >= 5) {
          action_updateMessage(item.custom_id, { is_read: 3 });
          return;
        }
        console.log('num', item.sendTotal, item);
      });
  }
};
