import parseBotDoc from '../components/chat-main/message-item/robot-message/parseBotDoc';
import { formatImgText, isJsonString } from '../utils/tools';
// 消息tip提示
// chatType: 0:单聊, 1:群聊
export const tipMessage = (message, im_id, chatType, uuid) => {
  try {
    let from_name = message?.name && chatType ? message.name + '：' : '';
    const docTypeMap = {
      1: '文档',
      2: 'Excel',
    };
    if (message.is_show === 0) {
      if (chatType === 0) {
        return `${message.uniq_id !== im_id ? '对方' : '你'}撤回了一条消息`;
      } else {
        return `${message.uniq_id !== im_id ? message.name || '' : '你'}撤回了一条消息`;
      }
    }
    if (
      message.msg_type === 'html' ||
      message.msg_type === 'text' ||
      message.msg_type === 'html_new'
    ) {
      if (message.msg_origin) {
        return (
          from_name +
          formatImgText(
            isJsonString(message.msg_origin)
              ? JSON.parse(message.msg_origin).msg
              : message.msg_origin,
          )
        );
      } else {
        return (
          from_name +
          formatImgText(isJsonString(message.msg) ? JSON.parse(message.msg).msg : message.msg)
        );
      }
    } else if (message.msg_type === 'image') {
      return from_name + '[图片]';
    } else if (message.msg_type === 'file') {
      return from_name + '[文件]';
    } else if (message.msg_type === 'location') {
      return from_name + '[位置]';
    } else if (message.msg_type === 'audio') {
      return from_name + '[语音]';
    } else if (message.msg_type == 'reply') {
      if (isJsonString(message.msg_origin)) {
        return formatImgText(JSON.parse(message.msg_origin).reply_msg);
      } else if (isJsonString(message.msg)) {
        return formatImgText(JSON.parse(message.msg).reply_msg);
      } else {
        return formatImgText(message.msg);
      }
    } else if (message.msg_type === 'robot_doc') {
      return parseBotDoc(JSON.parse(message.msg), uuid, im_id).title;
    } else if (message.msg_type == 'exit_channel') {
      return `${message.from_name}退出了群聊`;
    } else if (message.msg_type == 'join_channel') {
      return `欢迎${message.from_name}加入群聊`;
    } else if (message.msg_type == 'tip') {
      const msgJson = isJsonString(message.msg_origin)
        ? JSON.parse(message.msg_origin)
        : JSON.parse(message.msg);
      return `${msgJson.somebody?.name || ''}${msgJson.make}${msgJson.member_list[0]?.name || ''}${
        msgJson.something || ''
      }`;
    } else if (message.msg_type == 'custom') {
      switch (
        isJsonString(message.msg)
          ? JSON.parse(message.msg).type
          : JSON.parse(message.msg_origin).type
      ) {
        case 'groupInvite':
          return from_name + '[群聊邀请]';
        case 'quickin-company':
          return from_name + '[公司名片]';
        case 'companyWiki':
          return from_name + '[企业百科]';
        case 'news':
          return from_name + '[资讯]';
        case 'company':
          return from_name + '[服务窗]';
        case 'user':
          return from_name + '[工作名片]';
        case 'knowledge':
          return from_name + '[用户动态]';
        case 'mail':
          return from_name + '[工作名片]';
        case 'collection':
          return from_name + '[合集]';
        case 'product':
          return from_name + '[产品]';
        case 'recruit':
          return from_name + '[招聘]';
        case 'business':
          from_name + '[工商信息]';
      }
    } else if (message.msg_type == 'card') {
      return from_name + '[工作名片]';
    } else if (message.msg_type == 'robot_msg') {
      return from_name + '[科技快讯]';
    } else if (message.msg_type == 'doc') {
      const msgJson = JSON.parse(message.msg);
      return `[${docTypeMap[msgJson.type]}]${msgJson.name}`;
    } else if (!message.last_msg_id) {
      return '';
    } else {
      return '不支持此消息类型';
    }
  } catch (e) {
    return '暂不支持的消息';
  }
};
