import { ElMessage } from "element-plus";
// eslint-disable-next-line import/no-unresolved
import ClipboardJS from "clipboard";

function clipboardSuccess() {
  ElMessage.success("复制成功");
}

function clipboardError() {
  ElMessage.error("复制失败");
}

// 复制html片段
export function copyHtml(event: any, element: any) {
  const clipboard: any = new ClipboardJS(event.currentTarget, {
    target: function (trigger) {
      return element;
    },
  });
  clipboard.on("success", (e: any) => {
    clipboardSuccess();
    clipboard.off("error");
    clipboard.off("success");
    if (e.clearSelection) {
      e.clearSelection();
    }
    clipboard.destroy();
  });
  clipboard.on("error", (e: any) => {
    // fix: 复制html时只有一张图片会走error,e.text为空，其实是复制成功的
    clipboardSuccess();
    if (e.clearSelection) {
      e.clearSelection();
    }
    clipboard.off("error");
    clipboard.off("success");
    clipboard.destroy();
  });
  clipboard.onClick(event);
}

// 复制字符串到剪贴板（在非事件回调内不能使用clipboard库，只能模拟手动复制）
export function copyStr(str: string) {
  const el = document.createElement('textarea')
  // 添加一个特殊类名，方便区分是用户操作触发的复制还是通过调用该方法触发的复制
  el.className = 'copy-text-textarea'
  el.value = str + ''
  el.style.cssText = 'position: fixed; left: -99999px; z-index: -1'
  el.setAttribute('readonly', 'readonly') // 防止移动端唤起键盘
  document.body.appendChild(el)
  el.select()
  // 要想通过execCommand实现复制，必须得是input，textarea可输入元素，且输入框不能disabled且必须先调用select方法选中
  // 不调用或通过setSelectionRange实现选中都不行
  document.execCommand('Copy')
  clipboardSuccess()
  el.parentNode.removeChild(el)
}

// 剪贴板里的文字由于复制或者粘帖造成的两个\n,替换成一个
export const formatClipboardOneWrap = (e) => {
  e.preventDefault()
  const selection = window.getSelection(0)
  if (!selection) return
  const copyNode = selection.getRangeAt(0).cloneContents()
  let { text, html } = generateText(copyNode)
  const copyText = text.replace(/\n\n/g, '\n')
  // html = html.replace(/\n\n/g, '\n')
  if (e.clipboardData) {
    e.clipboardData.setData('text/plain', copyText)
    // e.clipboardData.setData('text/html', html)
  } else if (window.clipboardData) {
    return window.clipboardData.setData('text', copyText)
  }
}
/** 过滤节点生成复制的文字 */
const generateText = (copyNode: DocumentFragment) => {
  const div = document.createElement('div')
  div.appendChild(copyNode)
  document.body.appendChild(div)
  removeUserSelectDOM(div)
  // 获取过滤后的数据
  const text = div.innerText
  const html = div.innerHTML
  setTimeout(() => document.body.removeChild(div))
  return { text, html }
}
/** 过滤设user-select:none的节点 */
const removeUserSelectDOM = (div: HTMLElement) => {
  const nodeList = div.childNodes
  let removeList = []
  for (let i = 0; i < nodeList.length; i++) {
    const curNode: HTMLElement = nodeList[i]
    const nodeType = curNode.nodeType
    if (nodeType !== 1) continue
    const style = window?.getComputedStyle?.(curNode)
    if (style?.userSelect === 'none' || curNode.classList.contains('quote-msg')) {
      removeList.push(curNode)
    } else {
      curNode.childNodes?.length && removeUserSelectDOM(curNode)
    }
  }
  removeList.forEach((item) => {
    div.removeChild(item)
  })
}

// 权限询问
async function askWritePermission() {
  try {
    const { state } = await navigator.permissions.query({
      name: 'clipboard-write'
    })
    return state === 'granted'
  } catch (error) {
    return false
  }
}
// 复制图片
export async function writeImageToClipboard(url) {
  if (askWritePermission()) {
    if (navigator.clipboard && navigator.clipboard.write) {
      setCanvasImage(url, async (blob) => {
        try {
          // 只有png的图片才能复制到剪切板
          const item = new ClipboardItem({
            'image/png': blob,
          })
          await navigator.clipboard.write([item])
          clipboardSuccess()
        } catch (e) {
          console.log(e)
        }
      })
    }
  }
}
// 图片转为canvas
function setCanvasImage(path, func) {
  let img = new Image()
  let c = document.createElement('canvas')
  let ctx = c.getContext('2d')
  img.crossOrigin = 'anonymous'
  img.onload = function () {
    c.width = this.naturalWidth
    c.height = this.naturalHeight
    ctx.drawImage(this, 0, 0)
    c.toBlob(blob => {
      func(blob)
      img = null
      c = null
      ctx = null
    }, 'image/png')
  }
  img.src = path
}