import { getRegExp } from '@/utils/validate'

// v-hl={ kw: xxx, text: xxx }
// v-hl.bgc={ kw: xxx, text: xxx }（高亮背景色样式）
export default function (el, binding) {
  const { value = {}, oldValue = {} } = binding
  const { kw, text } = value
  if (kw === oldValue.kw && text === oldValue.text) return
  el.innerHTML = hl(text, kw, binding.modifiers.bgc, binding.modifiers.html)
}

export const hl = (text, kw, isBgcStyle = true, isHtml = false) => {
  if (!kw || !text) return text
  const reg = getRegExp(kw, 'gi')
  const replacement = `<span style="${isBgcStyle ? 'background-color: #FAE086' : 'color: red'}">$&</span>`
  if (isHtml) {
    return replaceHtmlText(text, reg, replacement)
  } else {
    return text.replace(reg, replacement)
  }
}

const HTML_TAG_REG = /(<\/?[^>]+>)/
export const replaceHtmlText = (html, reg, replacer) => {
  return (html || '')
    .split(HTML_TAG_REG) // 使用捕获分组将分隔字符也包含在结果数组内
    .map((t) => {
      if (t[0] === '<' && t[t.length - 1] === '>') {
        return t // html标签内不替换
      }
      if (reg instanceof RegExp) {
        reg.lastIndex = 0
      }
      return t.replace(reg, replacer)
    })
    .join('')
}
