import { computed, ref } from 'vue'

export function useInfiniteScroll(promiseFunction, idKey) {
  const dataList = ref([])
  const isEnd = ref(false)
  const scrollLoading = ref(false)
  const initLoading = ref(false)
  const pageNum = ref(1)
  const count = ref(0)
  const isEmpty = computed(() => !dataList.value.length)

  async function getData(reset) {
    if (reset) {
      isEnd.value = false
      scrollLoading.value = false
      pageNum.value = 1
    }
    if (isEnd.value || scrollLoading.value) return
    if (pageNum.value === 1) {
      initLoading.value = true
    }
    scrollLoading.value = true
    try {
      const currLastId = !dataList.value.length || reset ? '' : dataList.value[dataList.value.length - 1][idKey]
      const { list = [], count: totalCount = 0 } = await promiseFunction(pageNum.value++, currLastId)
      if (reset) {
        dataList.value.length = 0
      }
      if (!dataList.value.length) {
        dataList.value = list
      } else {
        dataList.value = [
          ...dataList.value,
          ...list.filter((e) => dataList.value.every((item) => item[idKey] !== e[idKey]))
        ]
      }
      count.value = +totalCount
      isEnd.value = dataList.value.length >= count.value
      return {
        list
      }
    } catch (e) {
      console.log(e)
    } finally {
      scrollLoading.value = false
      initLoading.value = false
    }
  }

  return {
    dataList,
    isEnd,
    isEmpty,
    scrollLoading,
    initLoading,
    count,
    pageNum,
    getData
  }
}
