/* 聊天会话相关状态 */
import { defineStore } from 'pinia';
import { asideList } from './chat/aside';
import chatDraftCache from '@/components/chat-module/msgUtils/chatDraftCache';
export const useUserImStore = defineStore('userImStore', {
  // 缓存字段
  persist: {
    paths: ['serviceList', 'serviceVersion'],
  },
  state: () => {
    return {
      // passport的uuid
      user_uuid: '',
      /* 未读消息数 */
      im_id: '',
      /* link IM id */
      user_im_id: '',
      related_msg_id: '', // 最近一条消息id
      cur_room_id: '', // 当前聊天room
      // 当前选择的Tab
      chatType: 'single',
      navList: [...asideList],
      // 我的企业
      has_account: null, // 是否为企业用户
      enterpriseList: [],
      draft: {},
      // 跳转信息
      jumpInfo: {},
      serviceVersion: 1,
      serviceList: [
        {
          city: '北京市',
          company: '企名片科技',
          icon: 'https://qmp.oss-cn-beijing.aliyuncs.com/im_file/202404/2024/04/14/13381063557/38571919_image_cropper_1713064888153.jpg',
          total: 0,
          name: '党壮',
          position: '董事长',
          school: '武汉大学',
          type: 'user',
          uniq_id: '13381063557',
          room_type: 0,
          room_id: '',
          is_dissolution: 0,
          in_channel: 1,
          is_show: 1,
          last_msg_info: {},
          create_time: '',
        },
        {
          city: '北京市',
          company: '企名片科技',
          icon: 'https://img1.qimingpian.cn/uploadImg/202402/65d8050ca4eab.png',
          total: 0,
          name: '龚卓星',
          position: '市场总监',
          school: '天津财经大学',
          type: 'user',
          uniq_id: '13807429400',
          room_type: 0,
          room_id: '',
          is_dissolution: 0,
          in_channel: 1,
          is_show: 1,
          last_msg_info: {},
          create_time: '',
        },
      ],
      source: 'see',
      otherParams: {}, // 获取会话列表其他参数
    };
  },
  getters: {
    // 全部未读数
    total() {
      const list = this.navList.filter(item => {
        return item.key === 'single';
      });
      return list.reduce((cur, item) => {
        return cur + item.unread;
      }, 0);
    },
  },
  actions: {
    async handleSelectMenu(item: any) {
      this.chatType = item.key;
      this.cur_room_id = '';
    },
    // 切换聊天菜单
    handleChatType(key: string) {
      const current = this.navList.find((item: any) => item.key === key);
      if (current) {
        this.handleSelectMenu(current);
      }
    },
    updateUserUnreadNum(unreadMap: any) {
      this.navList.map((menu: any) => {
        if (unreadMap[menu.key] !== undefined) {
          menu.unread = unreadMap[menu.key];
        }
      });
    },

    updateDraft(room_id: number, draft: any) {
      // 缓存内容，或回复
      if (draft && (draft.text || draft.reply?.id)) {
        this.draft[room_id] = draft.text || '回复';
        chatDraftCache.updateDraft(room_id, draft);
      } else {
        chatDraftCache.updateDraft(room_id, null);
        delete this.draft[room_id];
      }
    },
    LOGOUT_IM() {
      this.user_im_id = '';
    },
    // 重置部分信息
    resetData() {
      this.draft = {};
    },
  },
});
