// 日期中的单位数天前面添加0
export function toFormatDouble(num: number) {
  return num >= 10 ? num + '' : '0' + num
}
/*
 * 日期格式
 * 字符串格式: 年/月/日 时:分:秒
 */
export function formatTime(date: Date | string = new Date(), type = 'YYYY-MM-DD HH:mm:ss') {
  date = typeof date === 'string' ? new Date(date) : date
  const year = date.getFullYear()
  const month = toFormatDouble(date.getMonth() + 1)
  const day = toFormatDouble(date.getDate())
  const hour = toFormatDouble(date.getHours())
  const minute = toFormatDouble(date.getMinutes())
  const second = toFormatDouble(date.getSeconds())
  const time = JSON.parse(JSON.stringify(type))
  return time
    .replaceAll('YYYY', year)
    .replaceAll('MM', month)
    .replaceAll('DD', day)
    .replaceAll('HH', hour)
    .replaceAll('mm', minute)
    .replaceAll('ss', second)
}

/**
 * @description: 格式化im聊天时间
 * @param {*} str：时间字符串
 * @param {*} isAll：是否需要显示完整的昨天时间信息
 * @return {*}
 */
export function formatChatTime(str: string, isAll = true): string {
  // 如果为空，返回空
  if (!str) return ''
  const time = str.replace(/-/g, '/')
  const now = new Date()
  const target = new Date(time)

  const getTimeStr = (hour: number) => {
    if (hour < 6) {
      return `凌晨${hour}:${target.getMinutes() < 10 ? '0' : ''}${target.getMinutes()}`
    } else if (hour < 12) {
      return `上午${hour}:${target.getMinutes() < 10 ? '0' : ''}${target.getMinutes()}`
    } else if (hour < 14) {
      return `中午${hour}:${target.getMinutes() < 10 ? '0' : ''}${target.getMinutes()}`
    } else if (hour < 18) {
      return `下午${hour}:${target.getMinutes() < 10 ? '0' : ''}${target.getMinutes()}`
    } else {
      return `晚上${hour}:${target.getMinutes() < 10 ? '0' : ''}${target.getMinutes()}`
    }
  }

  // 判断参数时间是否为今天
  if (target.toDateString() === now.toDateString()) {
    const nowHour = now.getHours()
    const hour = target.getHours()
    const minuteDiff = now.getMinutes() - target.getMinutes()
    if (nowHour === hour && minuteDiff < 1) {
      return '刚刚'
    }
    return getTimeStr(hour)
  }

  // 判断参数时间是否为昨天
  const yesterday = new Date(now)
  yesterday.setDate(now.getDate() - 1)
  if (target.toDateString() === yesterday.toDateString()) {
    if (isAll) {
      return `昨天 ${getTimeStr(target.getHours())}`
    } else {
      return `昨天 ${target.getHours()}:${target.getMinutes() < 10 ? '0' : ''}${target.getMinutes()}`
    }
  }

  // 判断参数时间是否在今年之内
  if (now.getFullYear() === target.getFullYear()) {
    if (isAll) {
      return `${target.getMonth() + 1 < 10 ? '0' : ''}${target.getMonth() + 1}-${
        target.getDate() < 10 ? '0' : ''
      }${target.getDate()} ${getTimeStr(target.getHours())}`
    } else {
      return `${target.getMonth() + 1 < 10 ? '0' : ''}${target.getMonth() + 1}-${
        target.getDate() < 10 ? '0' : ''
      }${target.getDate()}`
    }
  }

  // 参数时间不是今年
  return `${target.getFullYear()}-${target.getMonth() + 1 < 10 ? '0' : ''}${target.getMonth() + 1}-${
    target.getDate() < 10 ? '0' : ''
  }${target.getDate()}`
}

// 获取一个当前时间的格式化日期
export function getFormatDate() {
  const date = new Date();
  const hh = date.getHours().toString().padStart(2, '0');
  const mm = date.getMinutes().toString().padStart(2, '0');
  const ss = date.getSeconds().toString().padStart(2, '0');
  const yy = date.getFullYear();
  const MM = (date.getMonth() + 1).toString().padStart(2, '0');
  const dd = date.getDate().toString().padStart(2, '0');
  const nowDate = yy + '-' + MM + '-' + dd + ' ' + hh + ':' + mm + ':' + ss;
  return nowDate;
}

// 计算两个日期的天数差
export function getDayNumByRangeTime(start:Date = new Date(), end: Date = new Date()) {
  const start_year = start.getFullYear()
  const start_month = start.getMonth()
  const start_day = start.getDate()
  const end_year = end.getFullYear()
  const end_month = end.getMonth()
  const end_day = end.getDate()
  return (new Date(end_year, end_month, end_day).getTime() - new Date(start_year, start_month, start_day).getTime())/(1000 * 60 * 60 * 24)
}

export function formatDurationTime(time: number, format = 'HH:mm:ss') {
  time = time * 1000
  let oneDay = 1000 * 60 * 60 * 24
  let oneHour = 1000 * 60 * 60
  let oneMinute = 1000 * 60
  let oneSecond = 1000
  let days = 0
  let hours: number | string = 0
  let minutes: number | string  = 0
  let seconds: number | string  = 0
  if (time >= oneDay) {
    days = Math.floor(time / oneDay)
    hours = Math.floor((time % oneDay) / oneHour)
    minutes = Math.floor((time % oneHour) / oneMinute)
  } else if (oneHour <= time && time < oneDay) {
    hours = Math.floor(time / oneHour)
    minutes = Math.floor((time % oneHour) / oneMinute)
    seconds = Math.floor(((time % oneHour) % oneMinute) / oneSecond)
  } else if (time >= oneMinute && time < oneHour) {
    minutes = Math.floor(time / oneMinute)
    seconds = Math.floor((time - minutes * oneMinute) / oneSecond)
  } else if (time >= oneSecond && time < oneMinute) {
    seconds = Math.floor(time / oneSecond)
  }
  if (hours < 10) {
    hours = '0' + hours
  }
  if (minutes < 10) {
    minutes = '0' + minutes
  }
  if (seconds < 10) {
    seconds = '0' + seconds
  }
  if (format === 'HH:mm:ss') {
    return (hours || '00') + ':' + (minutes || '00') + ':' + (seconds || '00')
  } else if (format === 'mm:ss') {
    return (minutes || '00') + ':' + (seconds || '00')
  } else {
    return { days, hours, minutes, seconds }
  }
}