export function getPaddingAndBorderSize(el: any) {
  const styleObj = getComputedStyle(el)
  const pl = parseInt(styleObj.paddingLeft)
  const pr = parseInt(styleObj.paddingRight)
  const pt = parseInt(styleObj.paddingTop)
  const pb = parseInt(styleObj.paddingBottom)

  const bl = parseInt(styleObj.borderLeftWidth)
  const br = parseInt(styleObj.borderRightWidth)
  const bt = parseInt(styleObj.borderTopWidth)
  const bb = parseInt(styleObj.borderBottomWidth)

  return {
    pl,
    pr,
    pt,
    pb,
    bl,
    br,
    bt,
    bb,
    bs: styleObj.boxSizing,
    px: pl + pr,
    py: pt + pb,
    bx: bl + br,
    by: bt + bb,
    x: pl + pr + bl + br,
    y: pt + pb + bt + bb
  }
}

export const isDOM = typeof HTMLElement === 'object'
  ? function (obj: any) {
    return obj instanceof HTMLElement
  }
  : function (obj: any) {
    return obj && typeof obj === 'object' && obj.nodeType === 1 && typeof obj.nodeName === 'string'
  }

export function getDOM(elOrSelector: any) {
  if (isDOM(elOrSelector)) return elOrSelector
  if (typeof elOrSelector === 'string') {
    return document.querySelector(elOrSelector)
  }
}

export function isAncestor(targetNode: any, ancestor: any) { // ancestor: dom 或 class字符串 或 class字符串数组
  const isAncestor = typeof ancestor === 'string'
    ? (targetNode: any, ancestor: any) => targetNode.classList && targetNode.classList.contains(ancestor) // class字符串
    : Array.isArray(ancestor)
      ? (targetNode: any, ancestor: any) => targetNode.classList && ancestor.some((className: string) => targetNode.classList.contains(className)) // class字符串数组
      : (targetNode: any, ancestor: any) => targetNode === ancestor // dom
  while (targetNode) {
    if (isAncestor(targetNode, ancestor)) return targetNode
    targetNode = targetNode.parentNode
  }
  return null
}
