import { markRaw } from 'vue'
import { getFileExt } from '@/utils/tools'
export const countries = markRaw([
  { areaName: '中国大陆', checkKey: /^(86){0,1}1\d{10}$/, countryCode: 'CN', phoneCode: '86' },
  {
    areaName: '中国香港',
    checkKey: /^(00){0,1}(852){1}0{0,1}[1,5,6,9](?:\d{7}|\d{8}|\d{12})$/,
    countryCode: 'HK',
    phoneCode: '852'
  },
  { areaName: '中国澳门', checkKey: /^(00){0,1}(853){1}6\d{7}$/, countryCode: 'MO', phoneCode: '853' },
  {
    areaName: '中国台湾地区',
    checkKey: /^(00){0,1}(886){1}0{0,1}[6,7,9](?:\d{7}|\d{8}|\d{10})$/,
    countryCode: 'TW',
    phoneCode: '886'
  },
  { areaName: '韩国', checkKey: /^(00){0,1}(82){1}0{0,1}[7,1](?:\d{8}|\d{9})$/, countryCode: 'KR', phoneCode: '82' },
  { areaName: '日本', checkKey: /^(00){0,1}(81){1}0{0,1}[7,8,9](?:\d{8}|\d{9})$/, countryCode: 'JP', phoneCode: '81' },
  { areaName: '美国', checkKey: /^(00){0,1}(1){1}\d{10,12}$/, countryCode: 'US', phoneCode: '1' },
  { areaName: '加拿大', checkKey: /^(00){0,1}(1){1}\d{10}$/, countryCode: 'CA', phoneCode: '1' },
  { areaName: '英国', checkKey: /^(00){0,1}(44){1}[347-9](\d{8,9}|\d{11,12})$/, countryCode: 'GB', phoneCode: '44' },
  { areaName: '澳大利亚', checkKey: /^(00){0,1}(61){1}4\d{8,9}$/, countryCode: 'AU', phoneCode: '61' },
  { areaName: '新加坡', checkKey: /^(00){0,1}(65){1}[13689]\d{6,7}$/, countryCode: 'SG', phoneCode: '65' },
  { areaName: '马来西亚', checkKey: /^(00){0,1}(60){1}1\d{8,9}$/, countryCode: 'MY', phoneCode: '60' },
  { areaName: '泰国', checkKey: /^(00){0,1}(66){1}[13456789]\d{7,8}$/, countryCode: 'TH', phoneCode: '66' },
  { areaName: '越南', checkKey: /^(00){0,1}(84){1}[1-9]\d{6,9}$/, countryCode: 'VN', phoneCode: '84' },
  { areaName: '菲律宾', checkKey: /^(00){0,1}(63){1}[24579](\d{7,9}|\d{12})$/, countryCode: 'PH', phoneCode: '63' },
  { areaName: '印度尼西亚', checkKey: /^(00){0,1}(62){1}[2-9]\d{7,11}$/, countryCode: 'ID', phoneCode: '62' },
  { areaName: '德国', checkKey: /^(00){0,1}(49){1}1(\d{5,6}|\d{9,12})$/, countryCode: 'DE', phoneCode: '49' },
  { areaName: '意大利', checkKey: /^(00){0,1}(39){1}[37]\d{8,11}$/, countryCode: 'IT', phoneCode: '39' },
  { areaName: '法国', checkKey: /^(00){0,1}(33){1}(\d{6}|\d{8,9})$/, countryCode: 'FR', phoneCode: '33' },
  { areaName: '俄罗斯', checkKey: /^(00){0,1}(7){1}[13489]\d{9,11}$/, countryCode: 'RU', phoneCode: '7' },
  { areaName: '新西兰', checkKey: /^(00){0,1}(64){1}[278]\d{7,9}$/, countryCode: 'NZ', phoneCode: '64' },
  { areaName: '荷兰', checkKey: /^(00){0,1}(31){1}6\d{8}$/, countryCode: 'NL', phoneCode: '31' },
  { areaName: '瑞典', checkKey: /^(00){0,1}(46){1}[124-7](\d{8}|\d{10}|\d{12})$/, countryCode: 'SE', phoneCode: '46' },
  { areaName: '乌克兰', checkKey: /^(00){0,1}(380){1}[3-79]\d{8,9}$/, countryCode: 'UA', phoneCode: '380' },
  { areaName: '阿联酋', checkKey: /^(00){0,1}(971){1}\d{6,12}$/, countryCode: 'AE', phoneCode: '971' },
  { areaName: '阿根廷', checkKey: /^(00){0,1}(54){1}\d{6,12}$/, countryCode: 'AR', phoneCode: '54' },
  { areaName: '奥地利', checkKey: /^(00){0,1}(43){1}\d{6,12}$/, countryCode: 'AT', phoneCode: '43' },
  { areaName: '比利时', checkKey: /^(00){0,1}(32){1}\d{6,12}$/, countryCode: 'BE', phoneCode: '32' },
  { areaName: '保加利亚', checkKey: /^(00){0,1}(359){1}\d{6,12}$/, countryCode: 'BG', phoneCode: '359' },
  { areaName: '巴西', checkKey: /^(00){0,1}(55){1}\d{6,12}$/, countryCode: 'BR', phoneCode: '55' },
  { areaName: '巴哈马', checkKey: /^(00){0,1}(1242){1}\d{6,12}$/, countryCode: 'BS', phoneCode: '1242' },
  { areaName: '白俄罗斯', checkKey: /^(00){0,1}(375){1}\d{6,12}$/, countryCode: 'BY', phoneCode: '375' },
  { areaName: '伯利兹', checkKey: /^(00){0,1}(501){1}\d{6,12}$/, countryCode: 'BZ', phoneCode: '501' },
  { areaName: '瑞士', checkKey: /^(00){0,1}(41){1}\d{6,12}$/, countryCode: 'CH', phoneCode: '41' },
  { areaName: '智利', checkKey: /^(00){0,1}(56){1}\d{6,12}$/, countryCode: 'CL', phoneCode: '56' },
  { areaName: '哥伦比亚', checkKey: /^(00){0,1}(57){1}\d{6,12}$/, countryCode: 'CO', phoneCode: '57' },
  { areaName: '丹麦', checkKey: /^(00){0,1}(45){1}\d{6,12}$/, countryCode: 'DK', phoneCode: '45' },
  { areaName: '爱沙尼亚', checkKey: /^(00){0,1}(372){1}\d{6,12}$/, countryCode: 'EE', phoneCode: '372' },
  { areaName: '埃及', checkKey: /^(00){0,1}(20){1}\d{6,12}$/, countryCode: 'EG', phoneCode: '20' },
  { areaName: '西班牙', checkKey: /^(00){0,1}(34){1}\d{6,12}$/, countryCode: 'ES', phoneCode: '34' },
  { areaName: '芬兰', checkKey: /^(00){0,1}(358){1}\d{6,12}$/, countryCode: 'FI', phoneCode: '358' },
  { areaName: '希腊', checkKey: /^(00){0,1}(30){1}\d{6,12}$/, countryCode: 'GR', phoneCode: '30' },
  { areaName: '匈牙利', checkKey: /^(00){0,1}(36){1}\d{6,12}$/, countryCode: 'HU', phoneCode: '36' },
  { areaName: '爱尔兰', checkKey: /^(00){0,1}(353){1}\d{6,12}$/, countryCode: 'IE', phoneCode: '353' },
  { areaName: '以色列', checkKey: /^(00){0,1}(972){1}\d{6,12}$/, countryCode: 'IL', phoneCode: '972' },
  { areaName: '印度', checkKey: /^(00){0,1}(91){1}\d{6,12}$/, countryCode: 'IN', phoneCode: '91' },
  { areaName: '约旦', checkKey: /^(00){0,1}(962){1}\d{6,12}$/, countryCode: 'JO', phoneCode: '962' },
  { areaName: '吉尔吉斯斯坦', checkKey: /^(00){0,1}(996){1}\d{6,12}$/, countryCode: 'KG', phoneCode: '996' },
  { areaName: '柬埔寨', checkKey: /^(00){0,1}(855){1}\d{6,12}$/, countryCode: 'KH', phoneCode: '855' },
  { areaName: '斯里兰卡', checkKey: /^(00){0,1}(94){1}\d{6,12}$/, countryCode: 'LK', phoneCode: '94' },
  { areaName: '立陶宛', checkKey: /^(00){0,1}(370){1}\d{6,12}$/, countryCode: 'LT', phoneCode: '370' },
  { areaName: '卢森堡', checkKey: /^(00){0,1}(352){1}\d{6,12}$/, countryCode: 'LU', phoneCode: '352' },
  { areaName: '摩洛哥', checkKey: /^(00){0,1}(212){1}\d{6,12}$/, countryCode: 'MA', phoneCode: '212' },
  { areaName: '蒙古', checkKey: /^(00){0,1}(976){1}\d{6,12}$/, countryCode: 'MN', phoneCode: '976' },
  { areaName: '马尔代夫', checkKey: /^(00){0,1}(960){1}\d{6,12}$/, countryCode: 'MV', phoneCode: '960' },
  { areaName: '墨西哥', checkKey: /^(00){0,1}(52){1}\d{6,12}$/, countryCode: 'MX', phoneCode: '52' },
  { areaName: '尼日利亚', checkKey: /^(00){0,1}(234){1}\d{6,12}$/, countryCode: 'NG', phoneCode: '234' },
  { areaName: '挪威', checkKey: /^(00){0,1}(47){1}\d{6,12}$/, countryCode: 'NO', phoneCode: '47' },
  { areaName: '巴拿马', checkKey: /^(00){0,1}(507){1}\d{6,12}$/, countryCode: 'PA', phoneCode: '507' },
  { areaName: '秘鲁', checkKey: /^(00){0,1}(51){1}\d{6,12}$/, countryCode: 'PE', phoneCode: '51' },
  { areaName: '波兰', checkKey: /^(00){0,1}(48){1}\d{6,12}$/, countryCode: 'PL', phoneCode: '48' },
  { areaName: '葡萄牙', checkKey: /^(00){0,1}(351){1}\d{6,12}$/, countryCode: 'PT', phoneCode: '351' },
  { areaName: '卡塔尔', checkKey: /^(00){0,1}(974){1}\d{6,12}$/, countryCode: 'QA', phoneCode: '974' },
  { areaName: '罗马尼亚', checkKey: /^(00){0,1}(40){1}\d{6,12}$/, countryCode: 'RO', phoneCode: '40' },
  { areaName: '塞尔维亚', checkKey: /^(00){0,1}(381){1}\d{6,12}$/, countryCode: 'SRB', phoneCode: '381' },
  { areaName: '沙特阿拉伯', checkKey: /^(00){0,1}(966){1}\d{6,12}$/, countryCode: 'SA', phoneCode: '966' },
  { areaName: '塞舌尔', checkKey: /^(00){0,1}(248){1}\d{6,12}$/, countryCode: 'SC', phoneCode: '248' },
  { areaName: '突尼斯', checkKey: /^(00){0,1}(216){1}\d{6,12}$/, countryCode: 'TN', phoneCode: '216' },
  { areaName: '土耳其', checkKey: /^(00){0,1}(90){1}\d{6,12}$/, countryCode: 'TR', phoneCode: '90' },
  { areaName: '委内瑞拉', checkKey: /^(00){0,1}(58){1}\d{6,12}$/, countryCode: 'VE', phoneCode: '58' },
  { areaName: '英属维尔京群岛', checkKey: /^(00){0,1}(1284){1}\d{6,12}$/, countryCode: 'VG', phoneCode: '1284' },
  { areaName: '南非', checkKey: /^(00){0,1}(27){1}\d{6,12}$/, countryCode: 'ZA', phoneCode: '27' },
  { areaName: '阿尔巴尼亚', checkKey: /^(00){0,1}(355){1}\d{6,15}$/, countryCode: 'AL', phoneCode: '355' },
  { areaName: '安哥拉', checkKey: /^(00){0,1}(244){1}\d{6,15}$/, countryCode: 'AO', phoneCode: '244' },
  { areaName: '阿塞拜疆', checkKey: /^(00){0,1}(994){1}\d{6,15}$/, countryCode: 'AZ', phoneCode: '994' },
  { areaName: '布基纳法索', checkKey: /^(00){0,1}(226){1}\d{6,15}$/, countryCode: 'BF', phoneCode: '226' },
  { areaName: '巴林', checkKey: /^(00){0,1}(973){1}\d{6,15}$/, countryCode: 'BH', phoneCode: '973' },
  { areaName: '贝宁', checkKey: /^(00){0,1}(229){1}\d{6,15}$/, countryCode: 'BJ', phoneCode: '229' },
  { areaName: '文莱', checkKey: /^(00){0,1}(673){1}\d{6,15}$/, countryCode: 'BN', phoneCode: '673' },
  { areaName: '玻利维亚', checkKey: /^(00){0,1}(591){1}\d{6,15}$/, countryCode: 'BO', phoneCode: '591' },
  { areaName: '喀麦隆', checkKey: /^(00){0,1}(237){1}\d{6,15}$/, countryCode: 'CM', phoneCode: '237' },
  { areaName: '哥斯达黎加', checkKey: /^(00){0,1}(506){1}\d{6,15}$/, countryCode: 'CR', phoneCode: '506' },
  { areaName: '佛得角', checkKey: /^(00){0,1}(238){1}\d{6,15}$/, countryCode: 'CV', phoneCode: '238' },
  { areaName: '塞浦路斯', checkKey: /^(00){0,1}(357){1}\d{6,15}$/, countryCode: 'CY', phoneCode: '357' },
  { areaName: '吉布提', checkKey: /^(00){0,1}(253){1}\d{6,15}$/, countryCode: 'DJ', phoneCode: '253' },
  { areaName: '加蓬', checkKey: /^(00){0,1}(241){1}\d{6,15}$/, countryCode: 'GA', phoneCode: '241' },
  { areaName: '格林纳达', checkKey: /^(00){0,1}(1473){1}\d{6,15}$/, countryCode: 'GD', phoneCode: '1473' },
  { areaName: '格鲁吉亚', checkKey: /^(00){0,1}(995){1}\d{6,15}$/, countryCode: 'GE', phoneCode: '995' },
  { areaName: '冈比亚', checkKey: /^(00){0,1}(220){1}\d{6,15}$/, countryCode: 'GM', phoneCode: '220' },
  { areaName: '几内亚', checkKey: /^(00){0,1}(224){1}\d{6,15}$/, countryCode: 'GN', phoneCode: '224' },
  { areaName: '赤道几内亚', checkKey: /^(00){0,1}(240){1}\d{6,15}$/, countryCode: 'GQ', phoneCode: '240' },
  { areaName: '危地马拉', checkKey: /^(00){0,1}(502){1}\d{6,15}$/, countryCode: 'GT', phoneCode: '502' },
  { areaName: '几内亚比绍', checkKey: /^(00){0,1}(245){1}\d{6,15}$/, countryCode: 'GW', phoneCode: '245' },
  { areaName: '圭亚那', checkKey: /^(00){0,1}(592){1}\d{6,15}$/, countryCode: 'GY', phoneCode: '592' },
  { areaName: '洪都拉斯', checkKey: /^(00){0,1}(504){1}\d{6,15}$/, countryCode: 'HN', phoneCode: '504' },
  { areaName: '克罗地亚', checkKey: /^(00){0,1}(385){1}\d{6,15}$/, countryCode: 'HR', phoneCode: '385' },
  { areaName: '牙买加', checkKey: /^(00){0,1}(1876){1}\d{6,15}$/, countryCode: 'JM', phoneCode: '1876' },
  { areaName: '肯尼亚', checkKey: /^(00){0,1}(254){1}\d{6,15}$/, countryCode: 'KE', phoneCode: '254' },
  { areaName: '科摩罗', checkKey: /^(00){0,1}(269){1}\d{6,15}$/, countryCode: 'KM', phoneCode: '269' },
  { areaName: '科威特', checkKey: /^(00){0,1}(965){1}\d{6,15}$/, countryCode: 'KW', phoneCode: '965' },
  { areaName: '开曼群岛', checkKey: /^(00){0,1}(1345){1}\d{6,15}$/, countryCode: 'KY', phoneCode: '1345' },
  { areaName: '莱索托', checkKey: /^(00){0,1}(266){1}\d{6,15}$/, countryCode: 'LS', phoneCode: '266' },
  { areaName: '拉脱维亚', checkKey: /^(00){0,1}(371){1}\d{6,15}$/, countryCode: 'LV', phoneCode: '371' },
  { areaName: '摩尔多瓦', checkKey: /^(00){0,1}(373){1}\d{6,15}$/, countryCode: 'MD', phoneCode: '373' },
  { areaName: '马达加斯加', checkKey: /^(00){0,1}(261){1}\d{6,15}$/, countryCode: 'MG', phoneCode: '261' },
  { areaName: '马里', checkKey: /^(00){0,1}(223){1}\d{6,15}$/, countryCode: 'ML', phoneCode: '223' },
  { areaName: '毛里塔尼亚', checkKey: /^(00){0,1}(222){1}\d{6,15}$/, countryCode: 'MR', phoneCode: '222' },
  { areaName: '毛里求斯', checkKey: /^(00){0,1}(230){1}\d{6,15}$/, countryCode: 'MU', phoneCode: '230' },
  { areaName: '马拉维', checkKey: /^(00){0,1}(265){1}\d{6,15}$/, countryCode: 'MW', phoneCode: '265' },
  { areaName: '莫桑比克', checkKey: /^(00){0,1}(258){1}\d{6,15}$/, countryCode: 'MZ', phoneCode: '258' },
  { areaName: '纳米比亚', checkKey: /^(00){0,1}(264){1}\d{6,15}$/, countryCode: 'NA', phoneCode: '264' },
  { areaName: '尼日尔', checkKey: /^(00){0,1}(227){1}\d{6,15}$/, countryCode: 'NE', phoneCode: '227' },
  { areaName: '尼加拉瓜', checkKey: /^(00){0,1}(505){1}\d{6,15}$/, countryCode: 'NI', phoneCode: '505' },
  { areaName: '阿曼', checkKey: /^(00){0,1}(968){1}\d{6,15}$/, countryCode: 'OM', phoneCode: '968' },
  { areaName: '巴布亚新几内亚', checkKey: /^(00){0,1}(675){1}\d{6,15}$/, countryCode: 'PG', phoneCode: '675' },
  { areaName: '巴勒斯坦', checkKey: /^(00){0,1}(970){1}\d{6,15}$/, countryCode: 'PS', phoneCode: '970' },
  { areaName: '卢旺达', checkKey: /^(00){0,1}(250){1}\d{6,15}$/, countryCode: 'RW', phoneCode: '250' },
  { areaName: '斯洛文尼亚', checkKey: /^(00){0,1}(386){1}\d{6,15}$/, countryCode: 'SI', phoneCode: '386' },
  { areaName: '斯洛伐克', checkKey: /^(00){0,1}(421){1}\d{6,15}$/, countryCode: 'SK', phoneCode: '421' },
  { areaName: '塞拉利昂', checkKey: /^(00){0,1}(232){1}\d{6,15}$/, countryCode: 'SL', phoneCode: '232' },
  { areaName: '塞内加尔', checkKey: /^(00){0,1}(221){1}\d{6,15}$/, countryCode: 'SN', phoneCode: '221' },
  { areaName: '苏里南', checkKey: /^(00){0,1}(597){1}\d{6,15}$/, countryCode: 'SR', phoneCode: '597' },
  { areaName: '萨尔瓦多', checkKey: /^(00){0,1}(503){1}\d{6,15}$/, countryCode: 'SV', phoneCode: '503' },
  { areaName: '斯威士兰', checkKey: /^(00){0,1}(268){1}\d{6,15}$/, countryCode: 'SZ', phoneCode: '268' },
  { areaName: '乍得', checkKey: /^(00){0,1}(235){1}\d{6,15}$/, countryCode: 'TD', phoneCode: '235' },
  { areaName: '多哥', checkKey: /^(00){0,1}(228){1}\d{6,15}$/, countryCode: 'TG', phoneCode: '228' },
  { areaName: '塔吉克斯坦', checkKey: /^(00){0,1}(992){1}\d{6,15}$/, countryCode: 'TJ', phoneCode: '992' },
  { areaName: '土库曼斯坦', checkKey: /^(00){0,1}(993){1}\d{6,15}$/, countryCode: 'TM', phoneCode: '993' },
  { areaName: '特立尼达和多巴哥', checkKey: /^(00){0,1}(1868){1}\d{6,15}$/, countryCode: 'TT', phoneCode: '1868' },
  { areaName: '坦桑尼亚', checkKey: /^(00){0,1}(255){1}\d{6,15}$/, countryCode: 'TZ', phoneCode: '255' },
  { areaName: '乌干达', checkKey: /^(00){0,1}(256){1}\d{6,15}$/, countryCode: 'UG', phoneCode: '256' },
  { areaName: '乌拉圭', checkKey: /^(00){0,1}(598){1}\d{6,15}$/, countryCode: 'UY', phoneCode: '598' },
  { areaName: '乌兹别克斯坦', checkKey: /^(00){0,1}(998){1}\d{6,15}$/, countryCode: 'UZ', phoneCode: '998' },
  { areaName: '也门', checkKey: /^(00){0,1}(967){1}\d{6,15}$/, countryCode: 'YE', phoneCode: '967' },
  { areaName: '赞比亚', checkKey: /^(00){0,1}(260){1}\d{6,15}$/, countryCode: 'ZM', phoneCode: '260' },
  { areaName: '津巴布韦', checkKey: /^(00){0,1}(263){1}\d{6,15}$/, countryCode: 'ZW', phoneCode: '263' },
  { areaName: '安道尔共和国', checkKey: /^(00){0,1}(376){1}\d{6,15}$/, countryCode: 'AD', phoneCode: '376' },
  { areaName: '阿富汗', checkKey: /^(00){0,1}(93){1}\d{6,15}$/, countryCode: 'AF', phoneCode: '93' },
  { areaName: '亚美尼亚', checkKey: /^(00){0,1}(374){1}\d{6,15}$/, countryCode: 'AM', phoneCode: '374' },
  { areaName: '波斯尼亚和黑塞哥维那', checkKey: /^(00){0,1}(387){1}\d{6,15}$/, countryCode: 'BA', phoneCode: '387' },
  { areaName: '孟加拉国', checkKey: /^(00){0,1}(880){1}\d{6,15}$/, countryCode: 'BD', phoneCode: '880' },
  { areaName: '布隆迪', checkKey: /^(00){0,1}(257){1}\d{6,15}$/, countryCode: 'BI', phoneCode: '257' },
  { areaName: '博茨瓦纳', checkKey: /^(00){0,1}(267){1}\d{6,15}$/, countryCode: 'BW', phoneCode: '267' },
  { areaName: '刚果(金)', checkKey: /^(00){0,1}(243){1}\d{6,15}$/, countryCode: 'CD', phoneCode: '243' },
  { areaName: '中非', checkKey: /^(00){0,1}(236){1}\d{6,15}$/, countryCode: 'CF', phoneCode: '236' },
  { areaName: '刚果(布)', checkKey: /^(00){0,1}(242){1}\d{6,15}$/, countryCode: 'CG', phoneCode: '242' },
  { areaName: '科特迪瓦', checkKey: /^(00){0,1}(225){1}\d{6,15}$/, countryCode: 'CI', phoneCode: '225' },
  { areaName: '库拉索岛', checkKey: /^(00){0,1}(599){1}\d{6,15}$/, countryCode: 'CW', phoneCode: '599' },
  { areaName: '捷克共和国', checkKey: /^(00){0,1}(420){1}\d{6,15}$/, countryCode: 'CZ', phoneCode: '420' },
  { areaName: '多米尼加共和国', checkKey: /^(00){0,1}(1809){1}\d{6,15}$/, countryCode: 'DO', phoneCode: '1809' },
  { areaName: '阿尔及利亚', checkKey: /^(00){0,1}(213){1}\d{6,15}$/, countryCode: 'DZ', phoneCode: '213' },
  { areaName: '厄瓜多尔', checkKey: /^(00){0,1}(593){1}\d{6,15}$/, countryCode: 'EC', phoneCode: '593' },
  { areaName: '加纳', checkKey: /^(00){0,1}(233){1}\d{6,15}$/, countryCode: 'GHA', phoneCode: '233' },
  { areaName: '伊拉克', checkKey: /^(00){0,1}(964){1}\d{6,15}$/, countryCode: 'IQ', phoneCode: '964' },
  { areaName: '哈萨克斯坦', checkKey: /^(00){0,1}(7){1}\d{6,15}$/, countryCode: 'KZ', phoneCode: '7' },
  { areaName: '老挝', checkKey: /^(00){0,1}(856){1}\d{6,15}$/, countryCode: 'LA', phoneCode: '856' },
  { areaName: '黎巴嫩', checkKey: /^(00){0,1}(961){1}\d{6,15}$/, countryCode: 'LB', phoneCode: '961' },
  { areaName: '利比里亚', checkKey: /^(00){0,1}(231){1}\d{6,15}$/, countryCode: 'LR', phoneCode: '231' },
  { areaName: '利比亚', checkKey: /^(00){0,1}(218){1}\d{6,15}$/, countryCode: 'LY', phoneCode: '218' },
  { areaName: '黑山共和国', checkKey: /^(00){0,1}(382){1}\d{6,15}$/, countryCode: 'ME', phoneCode: '382' },
  { areaName: '圣马丁', checkKey: /^(00){0,1}(590){1}\d{6,15}$/, countryCode: 'MF', phoneCode: '590' },
  { areaName: '马其顿', checkKey: /^(00){0,1}(389){1}\d{6,15}$/, countryCode: 'MK', phoneCode: '389' },
  { areaName: '缅甸', checkKey: /^(00){0,1}(95){1}\d{6,15}$/, countryCode: 'MM', phoneCode: '95' },
  { areaName: '巴基斯坦', checkKey: /^(00){0,1}(92){1}\d{6,15}$/, countryCode: 'PK', phoneCode: '92' },
  { areaName: '波多黎各', checkKey: /^(00){0,1}(1787){1}\d{6,15}$/, countryCode: 'PR', phoneCode: '1787' },
  { areaName: '索马里', checkKey: /^(00){0,1}(252){1}\d{6,15}$/, countryCode: 'SO', phoneCode: '252' },
  { areaName: '圣文森特和格林纳丁斯', checkKey: /^(00){0,1}(1784){1}\d{6,15}$/, countryCode: 'VC', phoneCode: '1784' },
  { areaName: '科索沃', checkKey: /^(00){0,1}(383){1}\d{6,15}$/, countryCode: 'XK', phoneCode: '383' },
  { areaName: '尼泊尔', checkKey: /^(00){0,1}(977){1}\d{6,15}$/, countryCode: 'NP', phoneCode: '977' },
  { areaName: '阿鲁巴', checkKey: /^(00){0,1}(297){1}\d{6,15}$/, countryCode: 'AW', phoneCode: '297' },
  { areaName: '巴巴多斯', checkKey: /^(00){0,1}(1246){1}\d{6,15}$/, countryCode: 'BB', phoneCode: '1246' },
  { areaName: '不丹', checkKey: /^(00){0,1}(975){1}\d{6,15}$/, countryCode: 'BT', phoneCode: '975' },
  { areaName: '库克群岛', checkKey: /^(00){0,1}(682){1}\d{6,15}$/, countryCode: 'CK', phoneCode: '682' },
  { areaName: '埃塞俄比亚', checkKey: /^(00){0,1}(251){1}\d{6,15}$/, countryCode: 'ET', phoneCode: '251' },
  { areaName: '斐济', checkKey: /^(00){0,1}(679){1}\d{6,15}$/, countryCode: 'FJ', phoneCode: '679' },
  { areaName: '密克罗尼西亚', checkKey: /^(00){0,1}(691){1}\d{6,15}$/, countryCode: 'FM', phoneCode: '691' },
  { areaName: '法罗群岛', checkKey: /^(00){0,1}(298){1}\d{6,15}$/, countryCode: 'FO', phoneCode: '298' },
  { areaName: '直布罗陀', checkKey: /^(00){0,1}(350){1}\d{6,15}$/, countryCode: 'GI', phoneCode: '350' },
  { areaName: '格陵兰岛', checkKey: /^(00){0,1}(299){1}\d{6,15}$/, countryCode: 'GL', phoneCode: '299' },
  { areaName: '关岛', checkKey: /^(00){0,1}(1671){1}\d{6,15}$/, countryCode: 'GU', phoneCode: '1671' },
  { areaName: '海地', checkKey: /^(00){0,1}(509){1}\d{6,15}$/, countryCode: 'HT', phoneCode: '509' },
  { areaName: '冰岛', checkKey: /^(00){0,1}(354){1}\d{6,15}$/, countryCode: 'IS', phoneCode: '354' },
  { areaName: '列支敦士登', checkKey: /^(00){0,1}(423){1}\d{6,15}$/, countryCode: 'LI', phoneCode: '423' },
  { areaName: '摩纳哥', checkKey: /^(00){0,1}(377){1}\d{6,15}$/, countryCode: 'MC', phoneCode: '377' },
  { areaName: '法属波利尼西亚', checkKey: /^(00){0,1}(689){1}\d{6,15}$/, countryCode: 'PF', phoneCode: '689' },
  { areaName: '帕劳', checkKey: /^(00){0,1}(680){1}\d{6,15}$/, countryCode: 'PW', phoneCode: '680' },
  { areaName: '巴拉圭', checkKey: /^(00){0,1}(595){1}\d{6,15}$/, countryCode: 'PY', phoneCode: '595' },
  { areaName: '所罗门群岛', checkKey: /^(00){0,1}(677){1}\d{6,15}$/, countryCode: 'SB', phoneCode: '677' },
  { areaName: '圣马力诺', checkKey: /^(00){0,1}(378){1}\d{6,15}$/, countryCode: 'SM', phoneCode: '378' },
  { areaName: '叙利亚', checkKey: /^(00){0,1}(963){1}\d{6,15}$/, countryCode: 'SY', phoneCode: '963' },
  { areaName: '汤加', checkKey: /^(00){0,1}(676){1}\d{6,15}$/, countryCode: 'TO', phoneCode: '676' },
  { areaName: '萨摩亚', checkKey: /^(00){0,1}(685){1}\d{6,15}$/, countryCode: 'WS', phoneCode: '685' },
  { areaName: '南极洲', checkKey: /^(00){0,1}(6723){1}\d{1,100}$/, countryCode: 'AQ', phoneCode: '672' },
  { areaName: '古巴', checkKey: /^(00){0,1}(53){1}\d{1,100}$/, countryCode: 'CU', phoneCode: '53' },
  { areaName: '西撒哈拉', checkKey: /^(00){0,1}(6723){1}\d{1,100}$/, countryCode: 'EH', phoneCode: '213' },
  { areaName: '厄立特里亚', checkKey: /^(00){0,1}(6723){1}\d{1,100}$/, countryCode: 'ER', phoneCode: '291' },
  { areaName: '瓜德罗普', checkKey: /^(00){0,1}(6723){1}\d{1,100}$/, countryCode: 'GP', phoneCode: '590' },
  { areaName: '泽西岛', checkKey: /^(00){0,1}(6723){1}\d{1,100}$/, countryCode: 'JEY', phoneCode: '44' },
  { areaName: '圣卢西亚', checkKey: /^(00){0,1}(1758){1}\d{1,100}$/, countryCode: 'LC', phoneCode: '1758' },
  {
    areaName: '南乔治亚岛和南桑威奇群岛',
    checkKey: /^(00){0,1}(6723){1}\d{1,100}$/,
    countryCode: 'SGS',
    phoneCode: '500'
  },
  { areaName: '圣赫勒拿岛', checkKey: /^(00){0,1}(6723){1}\d{1,100}$/, countryCode: 'SH', phoneCode: '290' },
  { areaName: '马约特', checkKey: /^(00){0,1}(2696){1}\d{1,100}$/, countryCode: 'YT', phoneCode: '2696' },
  { areaName: '诺福克岛', checkKey: /^(00){0,1}(6723){1}\d{1,100}$/, countryCode: 'NF', phoneCode: '6723' },
  { areaName: '马提尼克', checkKey: /^(00){0,1}(596){1}\d{1,100}$/, countryCode: 'MQ', phoneCode: '596' },
  { areaName: '马里亚那群岛', checkKey: /^(00){0,1}(1670){1}\d{1,100}$/, countryCode: 'MP', phoneCode: '1670' },
  { areaName: '伊朗', checkKey: /^(00){0,1}(98){1}\d{1,100}$/, countryCode: 'IR', phoneCode: '98' },
  { areaName: '百慕大群岛.', checkKey: /^(00){0,1}(1441){1}\d{1,100}$/, countryCode: 'BM', phoneCode: '1441' },
  { areaName: '荷属安的列斯', checkKey: /^(00){0,1}(599){1}\d{1,100}$/, countryCode: 'AN', phoneCode: '599' },
  { areaName: '美属萨摩亚', checkKey: /^(00){0,1}(684){1}\d{1,100}$/, countryCode: 'AS', phoneCode: '684' },
  { areaName: '新喀里多尼亚', checkKey: /^(00){0,1}(687){1}\d{1,100}$/, countryCode: 'NC', phoneCode: '687' },
  { areaName: '圣皮埃尔和密克隆岛', checkKey: /^(00){0,1}(508){1}\d{1,100}$/, countryCode: 'PM', phoneCode: '508' },
  { areaName: '留尼旺', checkKey: /^(00){0,1}(-4){1}\d{1,100}$/, countryCode: 'RE', phoneCode: '262' },
  { areaName: '苏丹', checkKey: /^(00){0,1}(249){1}\d{1,100}$/, countryCode: 'SD', phoneCode: '249' },
  { areaName: '瓦努阿图', checkKey: /^(00){0,1}(678){1}\d{1,100}$/, countryCode: 'VU', phoneCode: '678' },
  { areaName: '扎伊尔', checkKey: /^(00){0,1}(243){1}\d{1,100}$/, countryCode: 'ZR', phoneCode: '243' },
  { areaName: '马耳他', checkKey: /^(00){0,1}(356){1}\d{6,15}$/, countryCode: 'MT', phoneCode: '356' }
])
export const fileIconNameMap = {
  pdf: 'icon-link-desktopPDF',
  word: 'icon-link-desktopword1',
  excel: 'icon-link-desktopExcel',
  ppt: 'icon-link-desktopppt2',
  mind: 'icon-link-desktopnaotu',
  img: 'icon-link-desktoptupian1',
  audio: 'icon-link-desktopMP3',
  video: 'icon-link-desktopshipin',
  zip: 'icon-link-desktopyasuowenjian',
  txt: 'icon-link-desktopwenjiangeshi-txt',
  md: 'icon-link-desktopmarkdown',
  code: 'icon-link-desktopdaima1',
  file: 'icon-link-desktopzu-'
}

export const imgTypes = ['jpg', 'jpeg', 'png', 'gif', 'webp', 'bmp']
// 后缀文档类型
export const docTypes = ['epub', 'txt', 'doc', 'docx', 'xls', 'xlsx', 'pptx', 'pptx']
// 音频类型
export const audioTypes = ['mp3', 'wma']
// pdf类型
export const pdfType = ['pdf']

const browserSupportVideoTypes = ['mp4', 'mov', 'mkv']
const browserNotSupportVideoTypes = ['avi', 'flv', 'wmv', 'rmvb']
export const videoTypes = [...browserSupportVideoTypes, ...browserNotSupportVideoTypes]
/**
 * @param url
 * @param supportType{number[0,1]|undefined} 0:浏览器不支持 1:浏览器支持 不传:所有
 */
export const isVideoType = (url: string, supportType: number = undefined) => {
  const ext = url.length > 5 ? getFileExt(url) : url
  const arr =
    supportType === void 0 ? videoTypes : supportType === 1 ? browserSupportVideoTypes : browserNotSupportVideoTypes
  return arr.includes(ext)
}

export const getFileType = (fileExt: string) => {
  if (videoTypes.findIndex((item) => item === fileExt) !== -1) {
    return 4
  } else if (imgTypes.findIndex((item) => item == fileExt) !== -1) {
    return 3
  } else if (docTypes.findIndex((item) => item == fileExt) !== -1) {
    return 1
  } else if (audioTypes.findIndex((item) => item == fileExt) !== -1) {
    return 5
  } else if (pdfType.findIndex((item) => item == fileExt) !== -1) {
    return 2
  } else {
    return 99
  }
}

export const fileTypeIconMap = {
  ppt: fileIconNameMap.ppt,
  pptx: fileIconNameMap.ppt,
  doc: fileIconNameMap.word,
  docx: fileIconNameMap.word,
  pdf: fileIconNameMap.pdf,
  xls: fileIconNameMap.excel,
  xlsx: fileIconNameMap.excel,
  csv: fileIconNameMap.excel,
  jpg: fileIconNameMap.img,
  jpeg: fileIconNameMap.img,
  png: fileIconNameMap.img,
  gif: fileIconNameMap.img,
  webp: fileIconNameMap.img,
  rar: fileIconNameMap.zip,
  zip: fileIconNameMap.zip,
  '7z': fileIconNameMap.zip,
  mp3: fileIconNameMap.audio,
  wav: fileIconNameMap.audio,
  ...videoTypes.reduce((p, c) => {
    p[c] = fileIconNameMap.video
    return p
  }, {} as { [key: string]: string }),
  md: fileIconNameMap.md,
  txt: fileIconNameMap.txt,
  file: fileIconNameMap.file,
  html: fileIconNameMap.code,
  css: fileIconNameMap.code,
  js: fileIconNameMap.code,
  json: fileIconNameMap.code,
  php: fileIconNameMap.code,
  java: fileIconNameMap.code,
  c: fileIconNameMap.code,
  cpp: fileIconNameMap.code,
  py: fileIconNameMap.code
}
