export const getVideoInfo = (file) => new Promise((resolve, reject) => {
  const isFile = file instanceof File
  if (!(isFile || typeof file === 'string')) {
    throw new TypeError('file应为视频地址或file对象')
  }
  const v = document.createElement('video')
  if (isFile) {
    v.src = URL.createObjectURL(file)
  } else {
    v.src = file
  }
  v.onloadedmetadata = () => {
    resolve({
      duration: v.duration,
      width: v.videoWidth,
      height: v.videoHeight,
      scale: v.videoWidth / v.videoHeight
    })
    isFile && URL.revokeObjectURL(file)
  }
  v.onerror = (e) => {
    reject(e)
    isFile && URL.revokeObjectURL(file)
  }
})

/**
 * @param videoUrl{string}
 * @param second{number} 指定截取时间(毫秒)
 * @param width{number} 宽度
 * @param height{number?} 传了指定高度，不传会根据宽度自动去取一个合适的高
 */
export const getOssVideoCover = (videoUrl, second, width, height) => {
  return `${videoUrl}?x-oss-process=video/snapshot,t_${second},f_jpg,w_${width}${height !== void 0 ? ',h_' + height : ''}`
}