import { pinyinDict } from '@/utils/pinyin/dict'

function getPinyinList(char) {
  if (/\d/.test(char)) return [char]
  const res = [] // 可能为多音字，返回多个拼音
  for (const pinyin in pinyinDict) {
    const str = pinyinDict[pinyin]
    if (str.includes(char)) {
      res.push(pinyin)
    }
  }
  return res
}

// 李乐 -> [[li], [le, yue]] -> [[li, le], [li, yue]]
function getGroupPinyinList(pinyinList) {
  let res = []
  pinyinList.forEach(item => {
    if (res.length) {
      const newRes = []
      res.forEach(arr => {
        item.forEach(pinyin => {
          newRes.push([...arr, pinyin])
        })
      })
      res = newRes
    } else {
      res = item.map(pinyin => [pinyin])
    }
  })
  return res
}

export function isMatchWithPinyin(str, keywords, ignoreCase = true) {
  if (!keywords) return true
  if (!str) return false
  if (ignoreCase) {
    keywords = keywords.toLowerCase()
    str = str.toLowerCase()
  }
  if (str.includes(keywords)) return true
  if (/\W+/i.test(keywords)) return false
  // 开始判断拼音是否匹配
  const pinyinList = []
  for (const char of str) {
    const res = getPinyinList(char)
    if (res && res.length) {
      pinyinList.push(res)
    }
  }
  const groupPinyinList = getGroupPinyinList(pinyinList)
  return groupPinyinList.some(strPinyinList => {
    if (strPinyinList.map(pinyin => pinyin[0]).join('').includes(keywords)) {
      // 检查是否为每个字首字母
      return true
    }
    if (keywords.length <= 2) { // 当字母两个以下时，必须是某个字的拼音开始位置
      return strPinyinList.some(pinyin => pinyin.startsWith(keywords))
    } else { // 完整拼音
      return strPinyinList.join('').includes(keywords)
    }
  })
}

