import axios, { AxiosRequestConfig } from 'axios';
import { ElMessage } from 'element-plus';
import { ref } from 'vue';
import { trim } from '@/utils/tools';
import { onGetLSItem } from '@/utils/localStorage';
import { SOURCE } from '@/api/baseApi';
import decrypt from '@/utils/decryptLink';

/* 服务 */
export const service = axios.create({
  baseURL: '',
  timeout: 0,
});
/* 请求拦截器 */
service.interceptors.request.use(config => {
  const params = config.data || {};
  let paramsStr = '';
  // 不是线上环境 等于 测试
  params.decrypt = 1;
  params.uuid = onGetLSItem('link-token') || '';
  for (const i in params) {
    paramsStr += i + '=' + encodeURIComponent(trim(params[i])) + '&';
  }
  config.data = paramsStr.substring(0, paramsStr.length - 1);
  config.headers['Content-Type'] = 'application/x-www-form-urlencoded';
  config.headers['authorization'] = onGetLSItem('link-token') || '';
  config.headers['version'] = onGetLSItem('appVersion') || '1.0.0';
  config.headers['platform'] = 'pc';
  config.headers['source'] = SOURCE || 'see';
  return config;
});

const isShowMessageBox = ref(false);
const logoutList = [10001, 10004, 20001, 20002];
/* 响应拦截器 */
service.interceptors.response.use(({ data: res, config }) => {
  const params: any = config;
  if (logoutList.includes(res.status)) {
    return Promise.reject(res); // 终止接口返回
  }
  if (params?.config?.noMsg || res.status === 0) {
    if (res.encrypt_data) {
      // 加密
      res.data = decrypt(res.encrypt_data);
    }
    return res;
  } else {
    ElMessage({ type: 'error', message: res.message });
    return Promise.reject(res);
  }
});

const request = async (RequestConfig: AxiosRequestConfig) => {
  return await service(RequestConfig);
};

export const postRequest = ({
  url,
  data,
  config,
}: {
  url: string;
  data?: Record<string, any>;
  config?: Record<string, any>;
}) => {
  type ConfigParams = {
    method: string;
    url: string;
    data?: Record<string, any>;
    config?: Record<string, any>;
  };
  const params: ConfigParams = {
    method: 'post',
    url,
  };
  if (data) Object.assign(params, { data });
  if (config) Object.assign(params, { config });
  return request(params);
};
