import { imgTypes } from '@/utils/globalData'

// 形如 width: 20px;height: 30px;  a=1&b=2
export function getObjFromStr(str: string, split1 = ';', split2 = ':') {
  if (!str) return {}
  const obj: any = {}
  str.split(split1).forEach((item) => {
    const [key, val] = item.split(split2)
    if (val !== void 0) {
      obj[key] = val.trim()
    }
  })
  return obj
}
export function getQueryObj(url = window.location.href) {
  // url = decodeUrl(url)
  return getObjFromStr(url.split('?')[1] || '', '&', '=')
}
export function setClipboardText(str: string) {
  // 将一段文本放入剪贴板
  if (typeof str !== 'string') return Promise.reject()
  if (!navigator.clipboard) {
    window.getSelection().removeAllRanges()
    const inputEl = document.createElement('textarea')
    inputEl.value = str
    inputEl.style.cssText = 'position: absolute; bottom: 11111111; visible: hidden'
    document.appendChild(inputEl)
    setTimeout(() => {
      inputEl.select()
      document.execCommand('copy')
      return Promise.resolve()
    })
  } else {
    return navigator.clipboard.writeText(str)
  }
}

//  去掉空格
export function trim(str: any) {
  if (typeof str === 'string') {
    return str.replace(/(^\s*)|(\s*$)/g, '')
  } else {
    return str
  }
}

// 节流
export const throttle = (fn: Function, delay?: number) => {
  let Marking = true
  return (...args: any[]) => {
    if (!Marking) return
    fn.apply(this, args)
    Marking = false
    setTimeout(() => {
      Marking = true
    }, delay || 300)
  }
}
// 防颤抖
export const debounce = (fn: Function, delay?: number) => {
  let timer: any
  return (...args: any[]) => {
    clearTimeout(timer)
    timer = setTimeout(() => {
      fn.apply(this, args)
    }, delay || 300)
  }
}
// 不带协议的链接直接跳转会将当前origin拼接到链接，导致跳转不符合预期
export function getOpenHref(url: string) {
  url = url || ''
  if (!/^((http|https):\/\/)/.test(url)) {
    url = 'https://' + url
  }
  return url
}

export function fileToBase64(file: any) {
  return new Promise((resolve, reject) => {
    const reader = new FileReader()
    reader.readAsDataURL(file)
    reader.onload = () => resolve(reader.result)
    reader.onerror = (error) => reject(error)
  })
}

/*
 * 200.0 => 200, 200.10 => 200.1
 * @return: String
 * @params num(Number|String)
 * @params count(Number): 截取的小数位数
 * @params round(Boolean): 是否四舍五入，默认的toFixed方法会四舍五入
 * */
export function toFixed(num: any, count: any, round = true) {
  if (round) {
    num = (+num).toFixed(count)
  } else {
    const [integer, dot] = (num + '').split('.')
    if (dot === void 0) {
      // 无小数
      return integer
    } else {
      num = `${integer}.${dot.substr(0, count)}`
    }
  }
  return num.replace(/(\.\d+?)0+$/, '$1').replace(/\.0+$/, '')
}

export function getFileSize(size: any) {
  size = parseInt(size)
  const arr = ['B', 'KB', 'MB', 'GB']
  const length = arr.length
  for (let i = 0; i < length; i++) {
    if (size < 1024 || i === length - 1) {
      return toFixed(size, 1) + arr[i]
    }
    size = size / 1024
  }
}

// 获取8位随机字符
export const randomStr = (() => {
  function rx() {
    return (((1 + Math.random()) * 0x10000) | 0).toString(16).substring(1)
  }
  return () => {
    return rx() + rx()
  }
})()

export function getFileExt(fileName: string) {
  if (!fileName) return ''
  const splitArr = fileName.split('.')
  return splitArr.length === 1 ? '' : splitArr.pop().toLowerCase()
}

// 获取随机头像
export function getRandomAvatar() {
  const arr = [
    'https://img1.qimingpian.cn/uploadImg/202303/64196d494d2a0.png',
    'https://img1.qimingpian.cn/uploadImg/202303/64196d54300d6.png',
    'https://img1.qimingpian.cn/uploadImg/202303/64196d5e8a9c8.png',
    'https://img1.qimingpian.cn/uploadImg/202303/64196d6b37be1.png',
    'https://img1.qimingpian.cn/uploadImg/202303/64196d795b987.png',
    'https://img1.qimingpian.cn/uploadImg/202303/64196d8c99371.png'
  ]
  const index = Math.floor(Math.random() * 6) + 1
  return arr[index]
}
export function isImg(fileName, isExt = false) {
  if (!isExt) {
    fileName = getFileExt(fileName)
  }
  return imgTypes.includes(fileName)
}

/** 获取当前是星期几 */
export function getDay(day: string) {
  if (!day) return ''
  let weekArrayList = ['星期日', '星期一', '星期二', '星期三', '星期四', '星期五', '星期六']
  let index = new Date(day).getDay()
  let week = weekArrayList[index]
  return week
}
