import { defineConfig, loadEnv } from 'vite';
import vue from '@vitejs/plugin-vue';
import AutoImport from 'unplugin-auto-import/vite';
import Components from 'unplugin-vue-components/vite';
import ElementPlus from 'unplugin-element-plus/vite';
import { ElementPlusResolver } from 'unplugin-vue-components/resolvers';
import { createHtmlPlugin } from 'vite-plugin-html';
import { resolve } from 'path';
import WindiCSS from 'vite-plugin-windicss';

export default defineConfig({
  resolve: {
    alias: {
      '@': resolve(__dirname, './src'),
    },
  },
  css: {
    preprocessorOptions: {
      scss: {
        sourceMap: true,
        // additionalData: [`@import "./src/render/styles/mixin.scss";`],
        additionalData(source, fp) {
          // All scss files ending with imports.scss
          // will not re-import additionalData
          if (fp.endsWith('variables.scss') || fp.includes('node_modules')) {
            return source;
          }
          // Use additionalData from legacy nuxt scss options
          return `@import "./src/styles/variables.scss"; ${source}`;
        },
      },
    },
  },
  define: {
    'process.env.NODE_ENV': '"production"',
  },
  plugins: [
    vue(),
    WindiCSS(),
    createHtmlPlugin({
      inject: {
        ejsOptions: {},
      },
    }),
    AutoImport({
      resolvers: [
        ElementPlusResolver({
          importStyle: 'sass',
        }),
      ],
    }),
    Components({
      resolvers: [
        ElementPlusResolver({
          importStyle: 'sass',
        }),
      ],
    }),
    ElementPlus({
      useSource: true,
    }),
  ],
  build: {
    lib: {
      fileName: 'qmp-im-s',
      name: 'qmp-im-s',
      entry: resolve(__dirname, './export.ts'),
    },
    outDir: resolve(__dirname, 'lib'),
    rollupOptions: {
      output: {
        assetFileNames: `[name].[ext]`,
      },
      external: [
        'vue',
        'axios',
        'element-plus',
        '@element-plus/icons-vue',
        'pinia',
        'js-cookie',
        'upload-to-oss',
      ],
    },
    cssCodeSplit: true,
  },
});
